@@ -48,7 +48,6 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('wsgi/api_paste_config').with_value('api-paste.ini')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/use_forwarded_for').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with_value('5')
@@ -60,9 +59,9 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('api/max_limit').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('api/compute_link_prefix').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('api/glance_link_prefix').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/hide_server_address_states').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/allow_instance_snapshots').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/enable_network_quota').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/hide_server_address_states').with_ensure('absent')
+        is_expected.to contain_nova_config('api/allow_instance_snapshots').with_ensure('absent')
+        is_expected.to contain_nova_config('DEFAULT/enable_network_quota').with_ensure('absent')
         is_expected.to contain_nova_config('api/enable_instance_password').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/password_length').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with_value('<SERVICE DEFAULT>')
@@ -82,7 +81,6 @@ describe 'nova::api' do
           :metadata_listen                      => '127.0.0.1',
           :metadata_listen_port                 => 8875,
           :osapi_compute_listen_port            => 8874,
-          :use_forwarded_for                    => false,
           :osapi_compute_workers                => 1,
           :metadata_workers                     => 2,
           :enable_proxy_headers_parsing         => true,
@@ -90,9 +88,6 @@ describe 'nova::api' do
           :max_limit                            => 1000,
           :compute_link_prefix                  => 'https://10.0.0.1:7777/',
           :glance_link_prefix                   => 'https://10.0.0.1:6666/',
-          :hide_server_address_states           => 'building',
-          :allow_instance_snapshots             => true,
-          :enable_network_quota                 => false,
           :enable_instance_password             => true,
           :password_length                      => 12,
           :allow_resize_to_same_host            => true,
@@ -123,7 +118,6 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with_value('8874')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen').with_value('127.0.0.1')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with_value('8875')
-        is_expected.to contain_nova_config('api/use_forwarded_for').with_value(false)
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with_value('1')
         is_expected.to contain_nova_config('DEFAULT/metadata_workers').with_value('2')
         is_expected.to contain_nova_config('api/max_limit').with_value('1000')
@@ -133,9 +127,6 @@ describe 'nova::api' do
           :enable_proxy_headers_parsing => true,
           :max_request_body_size        => '102400',
         )
-        is_expected.to contain_nova_config('api/hide_server_address_states').with_value('building')
-        is_expected.to contain_nova_config('api/allow_instance_snapshots').with_value(true)
-        is_expected.to contain_nova_config('DEFAULT/enable_network_quota').with_value(false)
         is_expected.to contain_nova_config('api/enable_instance_password').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/password_length').with_value('12')
         is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with_value(true)
@@ -156,62 +147,10 @@ describe 'nova::api' do
       it { is_expected.to_not contain_service('nova-api') }
     end
 
-    context 'when running nova API in wsgi compute, and enabling metadata' do
-      before do
-        params.merge!({ :service_name => 'httpd' })
-      end
-
-      let :pre_condition do
-        "include apache
-         include nova
-         class { 'nova::keystone::authtoken':
-           password => 'a_big_secret',
-         }"
-      end
-
-      it 'enable nova API service' do
-        is_expected.to contain_service('nova-api').with(
-          :ensure => 'running',
-          :name   => platform_params[:nova_api_service],
-          :enable => true,
-          :tag    => 'nova-service',
-        )
-      end
-      it 'enable metadata in evenlet configuration' do
-        is_expected.to contain_nova_config('DEFAULT/enabled_apis').with_value('metadata')
-      end
-    end
-
-    context 'when running nova API in wsgi for compute, and disabling metadata' do
+    context 'when running nova API in wsgi for compute' do
       before do
         params.merge!({
           :service_name => 'httpd',
-          :enabled_apis => ['osapi_compute'] })
-      end
-
-      let :pre_condition do
-        "include apache
-         include nova
-         class { 'nova::keystone::authtoken':
-           password => 'a_big_secret',
-         }"
-      end
-
-      it 'disable nova API service' do
-        is_expected.to contain_service('nova-api').with(
-          :ensure => 'stopped',
-          :name   => platform_params[:nova_api_service],
-          :enable => false,
-          :tag    => 'nova-service',
-        )
-      end
-    end
-
-    context 'when running nova API in wsgi for compute, and metadata in wsgi' do
-      before do
-        params.merge!({
-          :service_name               => 'httpd',
-          :nova_metadata_wsgi_enabled => true
         })
       end
 
@@ -230,6 +169,10 @@ describe 'nova::api' do
           :enable => false,
           :tag    => 'nova-service',
         )
+        is_expected.to contain_nova_config('DEFAULT/enabled_apis').with_ensure('absent')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with_ensure('absent')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with_ensure('absent')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with_ensure('absent')
         is_expected.to contain_nova_config('DEFAULT/metadata_workers').with_ensure('absent')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen').with_ensure('absent')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with_ensure('absent')
