@@ -57,7 +57,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/cpu_power_governor_high').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/snapshots_directory').with_value('<SERVICE DEFAULT>')}
-      it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/inject_password').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/inject_key').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value('<SERVICE DEFAULT>')}
@@ -71,6 +71,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/file_backed_memory').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/images_type').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/volume_use_multipath').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/num_volume_scan_tries').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/num_pcie_ports').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/mem_stats_period_seconds').with_value('<SERVICE DEFAULT>')}
@@ -115,6 +116,7 @@ describe 'nova::compute::libvirt' do
           :file_backed_memory                         => 2048,
           :images_type                                => 'raw',
           :volume_use_multipath                       => false,
+          :num_volume_scan_tries                      => 3,
           :nfs_mount_options                          => 'rw,intr,nolock',
           :num_pcie_ports                             => 16,
           :mem_stats_period_seconds                   => 20,
@@ -158,6 +160,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/file_backed_memory').with_value(2048)}
       it { is_expected.to contain_nova_config('libvirt/images_type').with_value('raw')}
       it { is_expected.to contain_nova_config('libvirt/volume_use_multipath').with_value(false)}
+      it { is_expected.to contain_nova_config('libvirt/num_volume_scan_tries').with_value(3)}
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('rw,intr,nolock')}
       it { is_expected.to contain_nova_config('libvirt/num_pcie_ports').with_value(16)}
       it { is_expected.to contain_nova_config('libvirt/mem_stats_period_seconds').with_value(20)}
@@ -252,7 +255,6 @@ describe 'nova::compute::libvirt' do
         it { is_expected.not_to contain_package('libvirt') }
         it { is_expected.not_to contain_service('libvirt') }
         it { is_expected.not_to contain_package('libvirt-nwfilter') }
-        it { is_expected.not_to contain_service('messagebus') }
         it { is_expected.not_to contain_service('virtlockd') }
         it { is_expected.not_to contain_service('virtlogd') }
       end
@@ -282,12 +284,6 @@ describe 'nova::compute::libvirt' do
         :ensure => 'running',
         :before => ['Anchor[nova::service::end]', 'Service[nova-compute]'],
       )}
-      it { is_expected.to contain_service('messagebus').with(
-        :ensure => 'running',
-        :enable => true,
-        :before => ['Anchor[nova::service::end]', 'Service[libvirt]'],
-        :name   => 'dbus'
-      ) }
 
       it { is_expected.to contain_nova_config('DEFAULT/compute_driver').with_value('libvirt.LibvirtDriver')}
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('kvm')}
@@ -359,7 +355,6 @@ describe 'nova::compute::libvirt' do
         it { is_expected.not_to contain_package('libvirt') }
         it { is_expected.not_to contain_service('libvirt') }
         it { is_expected.not_to contain_package('libvirt-nwfilter') }
-        it { is_expected.not_to contain_service('messagebus') }
         it { is_expected.not_to contain_service('virtlockd') }
         it { is_expected.not_to contain_service('virtlogd') }
       end
