@@ -51,6 +51,7 @@ describe 'nova' do
           :kombu_ssl_version               => '<SERVICE DEFAULT>',
           :rabbit_ha_queues                => '<SERVICE DEFAULT>',
           :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
+          :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
           :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
           :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
@@ -131,6 +132,7 @@ describe 'nova' do
           :kombu_ssl_version                       => 'TLSv1',
           :rabbit_ha_queues                        => true,
           :rabbit_quorum_queue                     => true,
+          :rabbit_transient_quorum_queue           => true,
           :rabbit_quorum_delivery_limit            => 3,
           :rabbit_quorum_max_memory_length         => 5,
           :rabbit_quorum_max_memory_bytes          => 1073741824,
@@ -155,7 +157,6 @@ describe 'nova' do
           :report_interval                         => '10',
           :periodic_fuzzy_delay                    => '61',
           :ovsdb_connection                        => 'tcp:127.0.0.1:6640',
-          :upgrade_level_cert                      => '1.0.0',
           :upgrade_level_compute                   => '1.0.0',
           :upgrade_level_conductor                 => '1.0.0',
           :upgrade_level_scheduler                 => '1.0.0',
@@ -210,6 +211,7 @@ describe 'nova' do
           :kombu_ssl_version               => 'TLSv1',
           :rabbit_ha_queues                => true,
           :rabbit_quorum_queue             => true,
+          :rabbit_transient_quorum_queue   => true,
           :rabbit_quorum_delivery_limit    => 3,
           :rabbit_quorum_max_memory_length => 5,
           :rabbit_quorum_max_memory_bytes  => 1073741824,
@@ -240,7 +242,6 @@ describe 'nova' do
       end
 
       it 'configures upgrade_levels' do
-        is_expected.to contain_nova_config('upgrade_levels/cert').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/compute').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/conductor').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/scheduler').with_value('1.0.0')
@@ -355,10 +356,11 @@ describe 'nova' do
 
         it 'should install ssh private key' do
           is_expected.to contain_file("/var/lib/nova/.ssh/#{keyname}").with(
-            :content => 'keydata',
-            :mode    => '0600',
-            :owner   => 'nova',
-            :group   => 'nova',
+            :content   => 'keydata',
+            :mode      => '0600',
+            :owner     => 'nova',
+            :group     => 'nova',
+            :show_diff => false,
           )
         end
       end
@@ -374,7 +376,7 @@ describe 'nova' do
       it 'should raise an error' do
         expect {
           is_expected.to contain_file('/var/lib/nova/.ssh/id_rsa').with(
-            :content => 'keydata'
+            :content => 'keydata',
           )
         }.to raise_error Puppet::Error, /You must provide both a key type and key data./
       end
