@@ -35,17 +35,22 @@ describe 'nova::migration::libvirt' do
     context 'with default params' do
       it { is_expected.to contain_libvirtd_config('auth_tls').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('auth_tcp').with_value('none').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('key_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('cert_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_nova_config('libvirt/migration_inbound_addr').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_with_native_tls').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_bandwidth').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_downtime').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_downtime_steps').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_downtime_delay').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_timeout_action').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tcp://%s/system') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_inbound_addr').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('tcp') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_permit_post_copy').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/live_migration_permit_auto_converge').with_value('<SERVICE DEFAULT>')}
     end
@@ -61,17 +66,14 @@ describe 'nova::migration::libvirt' do
         :content => '0000-111-111',
       }).that_requires('Package[libvirt]') }
 
-      it { is_expected.to contain_augeas('libvirt-conf-uuid').with({
-        :context => '/files/etc/libvirt/libvirtd.conf',
-        :changes => [ "set host_uuid 0000-111-111" ],
-      }).that_requires('Package[libvirt]').that_notifies('Service[libvirt]') }
+      it { is_expected.to contain_libvirtd_config('host_uuid').with_value('0000-111-111').with_quote(true) }
     end
 
     context 'with override_uuid enabled and host_uuid set' do
       let :params do
         {
           :override_uuid => true,
-          :host_uuid => 'a8debd9d-e359-4bb2-8c77-edee431f94f2',
+          :host_uuid     => 'a8debd9d-e359-4bb2-8c77-edee431f94f2',
         }
       end
 
@@ -79,10 +81,7 @@ describe 'nova::migration::libvirt' do
         :content => 'a8debd9d-e359-4bb2-8c77-edee431f94f2',
       }).that_requires('Package[libvirt]') }
 
-      it { is_expected.to contain_augeas('libvirt-conf-uuid').with({
-        :context => '/files/etc/libvirt/libvirtd.conf',
-        :changes => [ "set host_uuid a8debd9d-e359-4bb2-8c77-edee431f94f2" ],
-      }).that_requires('Package[libvirt]').that_notifies('Service[libvirt]') }
+      it { is_expected.to contain_libvirtd_config('host_uuid').with_value('a8debd9d-e359-4bb2-8c77-edee431f94f2').with_quote(true) }
     end
 
     context 'with tls enabled' do
@@ -93,15 +92,19 @@ describe 'nova::migration::libvirt' do
       end
       it { is_expected.to contain_libvirtd_config('auth_tls').with_value('none').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('key_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('cert_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('tls') }
     end
 
     context 'with tls enabled and inbound addr set' do
       let :params do
         {
           :transport                   => 'tls',
+          :migration_inbound_addr      => 'host2.example.com',
           :live_migration_inbound_addr => 'host1.example.com',
         }
       end
@@ -109,8 +112,10 @@ describe 'nova::migration::libvirt' do
       it { is_expected.to contain_libvirtd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system')}
+      it { is_expected.to contain_nova_config('libvirt/migration_inbound_addr').with_value('host2.example.com')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_inbound_addr').with_value('host1.example.com')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('tls') }
     end
 
     context 'with live_migration_with_native_tls flags set' do
@@ -126,6 +131,7 @@ describe 'nova::migration::libvirt' do
       let :params do
         {
           :live_migration_tunnelled          => true,
+          :live_migration_bandwidth          => 1024,
           :live_migration_downtime           => 800,
           :live_migration_downtime_steps     => 15,
           :live_migration_downtime_delay     => 5,
@@ -134,6 +140,7 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with(:value => true) }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_bandwidth').with_value(1024) }
       it { is_expected.to contain_nova_config('libvirt/live_migration_downtime').with_value(800) }
       it { is_expected.to contain_nova_config('libvirt/live_migration_downtime_steps').with_value(15) }
       it { is_expected.to contain_nova_config('libvirt/live_migration_downtime_delay').with_value(5) }
@@ -160,6 +167,8 @@ describe 'nova::migration::libvirt' do
       end
       it { is_expected.to contain_libvirtd_config('auth_tls').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('auth_tcp').with_value('sasl').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('key_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('cert_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
     end
@@ -173,6 +182,8 @@ describe 'nova::migration::libvirt' do
       end
       it { is_expected.to contain_libvirtd_config('auth_tls').with_value('sasl').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('key_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('cert_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
     end
@@ -181,14 +192,18 @@ describe 'nova::migration::libvirt' do
       let :params do
         {
           :transport => 'tls',
-          :ca_file   => '/ca',
-          :crl_file  => '/crl',
+          :key_file  => '/etc/pki/libvirt/private/serverkey.pem',
+          :cert_file => '/etc/pki/libvirt/servercert.pem',
+          :ca_file   => '/etc/pki/CA/cacert.pem',
+          :crl_file  => '/etc/pki/CA/crl.pem',
         }
       end
       it { is_expected.to contain_libvirtd_config('auth_tls').with_value('none').with_quote(true) }
       it { is_expected.to contain_libvirtd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_libvirtd_config('ca_file').with_value('/ca').with_quote(true) }
-      it { is_expected.to contain_libvirtd_config('crl_file').with_value('/crl').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('key_file').with_value('/etc/pki/libvirt/private/serverkey.pem').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('cert_file').with_value('/etc/pki/libvirt/servercert.pem').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('ca_file').with_value('/etc/pki/CA/cacert.pem').with_quote(true) }
+      it { is_expected.to contain_libvirtd_config('crl_file').with_value('/etc/pki/CA/crl.pem').with_quote(true) }
     end
 
     context 'with auth set to an invalid setting' do
@@ -220,7 +235,9 @@ describe 'nova::migration::libvirt' do
           :transport      => 'tls',
         }
       end
-      it { is_expected.not_to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system') }
+      it { is_expected.not_to contain_nova_config('libvirt/live_migration_uri') }
+      it { is_expected.not_to contain_nova_config('libvirt/live_migration_inbound_addr') }
+      it { is_expected.not_to contain_nova_config('libvirt/live_migration_scheme') }
     end
 
     context 'with ssh transport' do
@@ -229,37 +246,41 @@ describe 'nova::migration::libvirt' do
           :transport => 'ssh',
         }
       end
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('ssh') }
     end
 
     context 'with ssh transport with user' do
       let :params do
         {
-          :transport => 'ssh',
+          :transport   => 'ssh',
           :client_user => 'foobar'
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://foobar@%s/system')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with ssh transport with port' do
       let :params do
         {
-          :transport => 'ssh',
+          :transport   => 'ssh',
           :client_port => 1234
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s:1234/system')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with ssh transport with extraparams' do
       let :params do
         {
-          :transport => 'ssh',
+          :transport          => 'ssh',
           :client_extraparams => {'foo' => '%', 'bar' => 'baz'}
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system?foo=%%25&bar=baz')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with tls transport' do
@@ -310,8 +331,9 @@ describe 'nova::migration::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/live_migration_with_native_tls').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_timeout_action').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tcp://%s/system') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_inbound_addr').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('tcp') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_permit_post_copy').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/live_migration_permit_auto_converge').with_value('<SERVICE DEFAULT>')}
     end
@@ -327,7 +349,8 @@ describe 'nova::migration::libvirt' do
       it { is_expected.to contain_virtproxyd_config('auth_tcp').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_virtproxyd_config('ca_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
       it { is_expected.to contain_virtproxyd_config('crl_file').with_value('<SERVICE DEFAULT>').with_quote(true) }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('tls') }
     end
 
     context 'with auth set to sasl' do
@@ -379,7 +402,8 @@ describe 'nova::migration::libvirt' do
           :modular_libvirt => true,
         }
       end
-      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('ssh') }
     end
 
     context 'with ssh transport with user' do
@@ -391,6 +415,7 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://foobar@%s/system')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_scheme').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with ssh transport with port' do
